package cn.com.ctop.kuaishou.modules.dimension.controller;

import cn.com.ctop.common.module.entity.CtopOauthToken;
import cn.com.ctop.common.module.service.ICtopOauthTokenService;
import cn.com.ctop.common.module.utils.Check;
import cn.com.ctop.common.module.utils.QueryGenerator;
import cn.com.ctop.kuaishou.modules.batch.service.IKuaiShouVideoGetService;
import cn.com.ctop.kuaishou.modules.dimension.entity.KuaiShouDimensionCreative;
import cn.com.ctop.kuaishou.modules.dimension.service.IKuaiShouDimensionCreativeService;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.util.oConvertUtils;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/**
 * 多维度测试关联创意
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2021-07-22
 */
@Slf4j
@Api(tags = "多维度测试关联创意")
@RestController
@RequestMapping("/dimension/kuaiShouDimensionCreative")
public class KuaiShouDimensionCreativeController {
    @Autowired
    private IKuaiShouDimensionCreativeService kuaiShouDimensionCreativeService;
    @Autowired
    private ICtopOauthTokenService oauthTokenService;
    static ExecutorService accountCreativeService = Executors.newFixedThreadPool(10);
    @Autowired
    private IKuaiShouVideoGetService videoGetService;


    @ApiOperation(value = "多维度测试关联创意-分页列表查询", notes = "多维度测试关联创意-分页列表查询")
    @GetMapping(value = "/againCreateCreative")
    public void againCreateCreative(Long accountId) {
        if (Check.isNull(accountId)) {
            log.error("账户id不能为空");
            return;
        }
        CtopOauthToken token = oauthTokenService.getTokenByAccountId(accountId);
        if (Check.isNull(token)) {
            log.error("未获取到授权信息，账户id”{}", accountId);
            return;
        }
        accountCreativeService.submit(new Runnable() {
            @Override
            public void run() {
                log.info("账户待重提创意开始创建，accountId：{}", accountId);
                kuaiShouDimensionCreativeService.againCreateCreative(accountId, token.getAccessToken());
            }
        });
    }


    @ApiOperation(value = "多维度测试关联创意-分页列表查询", notes = "多维度测试关联创意-分页列表查询")
    @GetMapping(value = "/getCreativeList")
    public Result<List<KuaiShouDimensionCreative>> getCreativeList(String unitTableId) {
        Result<List<KuaiShouDimensionCreative>> result = new Result<>();
        QueryWrapper<KuaiShouDimensionCreative> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("unit_table_id", unitTableId);
        List<KuaiShouDimensionCreative> list = kuaiShouDimensionCreativeService.list(queryWrapper);
        for (KuaiShouDimensionCreative creative : list) {
            JSONObject videoJson = videoGetService.getVideoByPhotoIdAndAccountId(creative.getAccountId(), creative.getPhotoId());
            if (!Check.isNull(videoJson)) {
                creative.setCoverUrl(videoJson.getString("coverUrl"));
                creative.setPhotoUrl(videoJson.getString("photoUrl"));
            }
        }

        result.setSuccess(true);
        result.setResult(list);
        return result;
    }

    /**
     * 添加
     *
     * @param kuaiShouDimensionCreative
     * @return
     */
    @ApiOperation(value = "多维度测试关联创意-添加", notes = "多维度测试关联创意-添加")
    @PostMapping(value = "/add")
    public Result<KuaiShouDimensionCreative> add(@RequestBody KuaiShouDimensionCreative kuaiShouDimensionCreative) {
        Result<KuaiShouDimensionCreative> result = new Result<>();
        try {
            kuaiShouDimensionCreativeService.save(kuaiShouDimensionCreative);
            result.success("添加成功！");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("操作失败");
        }
        return result;
    }

    /**
     * 编辑
     *
     * @param kuaiShouDimensionCreative
     * @return
     */
    @ApiOperation(value = "多维度测试关联创意-编辑", notes = "多维度测试关联创意-编辑")
    @PutMapping(value = "/edit")
    public Result<KuaiShouDimensionCreative> edit(@RequestBody KuaiShouDimensionCreative kuaiShouDimensionCreative) {
        Result<KuaiShouDimensionCreative> result = new Result<KuaiShouDimensionCreative>();
        KuaiShouDimensionCreative kuaiShouDimensionCreativeEntity = kuaiShouDimensionCreativeService.getById(kuaiShouDimensionCreative.getId());
        if (kuaiShouDimensionCreativeEntity == null) {
            result.error500("未找到对应实体");
        } else {
            boolean ok = kuaiShouDimensionCreativeService.updateById(kuaiShouDimensionCreative);
            if (ok) {
                result.success("修改成功!");
            }
        }

        return result;
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @ApiOperation(value = "多维度测试关联创意-通过id删除", notes = "多维度测试关联创意-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name = "id") String id) {
        try {
            kuaiShouDimensionCreativeService.removeById(id);
        } catch (Exception e) {
            log.error("删除失败", e.getMessage());
            return Result.error("删除失败!");
        }
        return Result.ok("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @ApiOperation(value = "多维度测试关联创意-批量删除", notes = "多维度测试关联创意-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<KuaiShouDimensionCreative> deleteBatch(@RequestParam(name = "ids") String ids) {
        Result<KuaiShouDimensionCreative> result = new Result<>();
        if (ids == null || "".equals(ids.trim())) {
            result.error500("参数不识别！");
        } else {
            this.kuaiShouDimensionCreativeService.removeByIds(Arrays.asList(ids.split(",")));
            result.success("删除成功!");
        }
        return result;
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @ApiOperation(value = "多维度测试关联创意-通过id查询", notes = "多维度测试关联创意-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<KuaiShouDimensionCreative> queryById(@RequestParam(name = "id", required = true) String id) {
        Result<KuaiShouDimensionCreative> result = new Result<>();
        KuaiShouDimensionCreative kuaiShouDimensionCreative = kuaiShouDimensionCreativeService.getById(id);
        if (kuaiShouDimensionCreative == null) {
            result.error500("未找到对应实体");
        } else {
            result.setResult(kuaiShouDimensionCreative);
            result.setSuccess(true);
        }
        return result;
    }

    /**
     * 导出excel
     *
     * @param request
     * @param response
     */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HttpServletResponse response) {
        // Step.1 组装查询条件
        QueryWrapper<KuaiShouDimensionCreative> queryWrapper = null;
        try {
            String paramsStr = request.getParameter("paramsStr");
            if (oConvertUtils.isNotEmpty(paramsStr)) {
                String deString = URLDecoder.decode(paramsStr, "UTF-8");
                KuaiShouDimensionCreative kuaiShouDimensionCreative = JSON.parseObject(deString, KuaiShouDimensionCreative.class);
                queryWrapper = QueryGenerator.initQueryWrapper(kuaiShouDimensionCreative, request.getParameterMap());
            }
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }

        //Step.2 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        List<KuaiShouDimensionCreative> pageList = kuaiShouDimensionCreativeService.list(queryWrapper);
        //导出文件名称
        mv.addObject(NormalExcelConstants.FILE_NAME, "多维度测试关联创意列表");
        mv.addObject(NormalExcelConstants.CLASS, KuaiShouDimensionCreative.class);
        mv.addObject(NormalExcelConstants.PARAMS, new ExportParams("多维度测试关联创意列表数据", "导出人:Jeecg", "导出信息"));
        mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
        return mv;
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            MultipartFile file = entity.getValue();
            ImportParams params = new ImportParams();
            params.setTitleRows(2);
            params.setHeadRows(1);
            params.setNeedSave(true);
            try {
                List<KuaiShouDimensionCreative> listKuaiShouDimensionCreatives = ExcelImportUtil.importExcel(file.getInputStream(), KuaiShouDimensionCreative.class, params);
                kuaiShouDimensionCreativeService.saveBatch(listKuaiShouDimensionCreatives);
                return Result.ok("文件导入成功！数据行数:" + listKuaiShouDimensionCreatives.size());
            } catch (Exception e) {
                log.error(e.getMessage(), e);
                return Result.error("文件导入失败:" + e.getMessage());
            } finally {
                try {
                    file.getInputStream().close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return Result.ok("文件导入失败！");
    }

}
